#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 insert-ordered-containers
version:              0.2.5.3
visibility:           public
id:                   insert-ordered-containers-0.2.5.3-8Jd9ICZr65OKd3nnw0HEIa
key:                  insert-ordered-containers-0.2.5.3-8Jd9ICZr65OKd3nnw0HEIa
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/insert-ordered-containers#readme
synopsis:
    Associative containers retaining insertion order for traversals.

description:
    Associative containers retaining insertion order for traversals.

    The implementation is based on `unordered-containers`.

category:             Web
abi:                  2b98de07c041fd1fb84e2c2c8cb5fe7d
exposed:              True
exposed-modules:      Data.HashMap.Strict.InsOrd Data.HashSet.InsOrd
hidden-modules:       Data.HashMap.InsOrd.Internal
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/insert-ordered-containers-0.2.5.3

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/insert-ordered-containers-0.2.5.3

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/insert-ordered-containers-0.2.5.3

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-insert-ordered-containers
hs-libraries:         HSinsert-ordered-containers-0.2.5.3-8Jd9ICZr65OKd3nnw0HEIa
depends:
    aeson-2.2.1.0-IFj7FSeQ5R79PZnh3ksXrW base-4.18.2.1 deepseq-1.4.8.1
    hashable-1.4.7.0-JuZCUcgZ6993MAquoa2cCW
    indexed-traversable-0.1.4-8j5HZpShpE5BqFup9Ojenr
    lens-5.3.4-9D2yk6aQnpf3ebTPLPYG20
    optics-core-0.4.2-J18Nb2IXjjh13vl8kUWmGX
    optics-extra-0.4.2.1-Ej7zQADnO7LFifZFqoxdit
    semigroupoids-6.0.2-5KpCoZ3FBsyCetKjS7KKeX text-2.0.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-24qNbjJ9xXJll0vtFCYfq

haddock-interfaces:
    /usr/share/doc/haskell-insert-ordered-containers/html/insert-ordered-containers.haddock

haddock-html:         /usr/share/doc/haskell-insert-ordered-containers/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

